/*
 * google-geocoding-api-client
 */

"use strict";

// HTTP client
const axios = require('axios');

module.exports = function (geocodingConfig) {

	const googleGeocodingApiClientMixIn = {

		methods: {

			/**
			 * Get conventional address from location and country-province-city name to Spirits population.
			 * 
			 * @param {*} latitude 
			 * @param {*} longitude 
			 */
			async geoDecodeByLocation(latitude, longitude) {
				const config = {
					method: 'get',
					url: geocodingConfig.url + "latlng=" + latitude + "," + longitude + "&key=" + geocodingConfig.key
				};
				const rsp = await axios(config);
				const addressComponents = rsp.data.results[0].address_components;
				const street = addressComponents.find(ac => ac.types[0] == "street_number").long_name;
				const number = addressComponents.find(ac => ac.types[0] == "route").long_name;
				const zip = addressComponents.find(ac => ac.types[0] == "postal_code").long_name;
				const city = addressComponents.find(ac => ac.types[0] == "locality").long_name;
				const province = addressComponents.find(ac => ac.types[0] == "administrative_area_level_1").long_name;
				const country = addressComponents.find(ac => ac.types[0] == "country").long_name;
				return {
					street: street,
					number: number,
					zip: zip,
					city: city,
					province: province,
					country: country
				};
			},

			/**
			 * Get location from conventional address and province name to Spirits population (city and country well done on start-up).
			 * 
			 * @param {*} street 
			 * @param {*} number 
			 * @param {*} zip 
			 * @param {*} city 
			 * @param {*} country 
			 */
			async geoDecodeByAddress(street, number, zip, city, country) {
				const config = {
					method: 'get',
					url: geocodingConfig.url + "address=" + number + " " + street + "," + zip + "," + city + "," + country + "&key=" + geocodingConfig.key
				};
				const rsp = await axios(config);
				const location = rsp.data.results[0].geometry.location;
				const province = rsp.data.results[0].address_components.find(ac => ac.types[0] == "administrative_area_level_1").long_name;
				return {
					latitude: location.lat,
					longitude: location.lng,
					province: province
				};
			}
		},

		/**
		 * Mixin init.
		 */
		async created() {
			console.info("geocoding-api-client init....");
			console.info("geocoding-api-client OK!");
		}
	};

	return googleGeocodingApiClientMixIn;
};
